@@ -107,26 +107,39 @@ static void Lazy_RunConfScript (rivet_thread_private* private,lazy_tcl_worker* w
         case child_global: function = w->conf->rivet_global_init_script;
                            break;
         case child_init: function = w->conf->rivet_child_init_script;
-                           break;
+                         break;
         case child_exit: function = w->conf->rivet_child_exit_script;
     }
 
     if (function)
     {
+        rivet_interp_globals* globals = NULL;
         tcl_conf_script = Tcl_NewStringObj(function,-1);
         Tcl_IncrRefCount(tcl_conf_script);
 
+        /* before we run a script we have to store the pointer to the
+         * running configuration in the thread private data. The design has
+         * to improve and running a script must have everything sanely
+         * prepared TODO
+         */
+
+        globals = Tcl_GetAssocData(interp,"rivet",NULL);
+
+        /*
+         * The current server record is stored to enable ::rivet::apache_log_error and
+         * other commands to log error messages in the virtual host's designated log file
+         */
+
+        globals->server = w->server;
+
         if (Tcl_EvalObjEx(interp,tcl_conf_script, 0) != TCL_OK)
         {
             char*       errmsg = "rivet_lazy_mpm.so: Error in configuration script: %s";
             server_rec* root_server = module_globals->server;
 
-            ap_log_error(APLOG_MARK, APLOG_ERR, APR_EGENERAL,root_server,
-                         errmsg, function);
-            ap_log_error(APLOG_MARK, APLOG_ERR, APR_EGENERAL,root_server,
-                         "errorCode: %s", Tcl_GetVar(interp, "errorCode", 0));
-            ap_log_error(APLOG_MARK, APLOG_ERR, APR_EGENERAL,root_server,
-                         "errorInfo: %s", Tcl_GetVar(interp, "errorInfo", 0));
+            ap_log_error(APLOG_MARK,APLOG_ERR,APR_EGENERAL,root_server,errmsg,function);
+            ap_log_error(APLOG_MARK,APLOG_ERR,APR_EGENERAL,root_server,"errorCode: %s", Tcl_GetVar(interp, "errorCode", 0));
+            ap_log_error(APLOG_MARK,APLOG_ERR,APR_EGENERAL,root_server,"errorInfo: %s", Tcl_GetVar(interp, "errorInfo", 0));
         }
 
         Tcl_DecrRefCount(tcl_conf_script);
@@ -136,10 +149,10 @@ static void Lazy_RunConfScript (rivet_thread_private* private,lazy_tcl_worker* w
 /*
  * -- request_processor
  *
- * The lazy bridge worker thread. This thread prepares its control data and
- * will serve requests addressed to a given virtual host. Virtual host server
- * data are stored in the lazy_tcl_worker structure stored in the generic
- * pointer argument 'data'
+ * The lazy bridge worker thread. This thread initializes its control data and
+ * prepares to serve requests addressed to the virtual host which is meant to work
+ * as a content generator. Virtual host server data are stored in the
+ * lazy_tcl_worker structure stored in the generic pointer argument 'data'
  *
  */
 
@@ -183,7 +196,7 @@ static void* APR_THREAD_FUNC request_processor (apr_thread_t *thd, void *data)
 
     Rivet_PerInterpInit(private->ext->interp,private,w->server,private->pool);
 
-    /* The child initialization is fired. Beware of the terminologic
+    /* The child initialization is fired. Beware the terminological
      * trap: we inherited from fork capable systems the term 'child'
      * meaning 'child process'. In this case the child init actually
      * is a worker thread initialization, because in a threaded module
@@ -369,8 +382,9 @@ int LazyBridge_Request (request_rec* r,rivet_req_ctype ctype)
      * be avoided at any costs when programming with mod_rivet
      */
 
-    if (module_globals->mpm->server_shutdown == 1) {
-        ap_log_rerror(APLOG_MARK, APLOG_ERR, APR_EGENERAL, r,
+    if (module_globals->mpm->server_shutdown == 1)
+    {
+        ap_log_rerror(APLOG_MARK,APLOG_ERR,APR_EGENERAL,r,
                       MODNAME ": http request aborted during child process shutdown");
         apr_thread_mutex_unlock(mutex);
         return HTTP_INTERNAL_SERVER_ERROR;
@@ -494,7 +508,6 @@ apr_status_t LazyBridge_Finalize (void* data)
  *
  */
 
-
 int LazyBridge_ExitHandler(rivet_thread_private* private)
 {
 
